@@ -1,25 +1,17 @@
 package font
 
 import (
-	"encoding/gob"
-
 	"github.com/jandedobbeleer/oh-my-posh/src/dsc"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 )
 
-func init() {
-	gob.Register([]*Font{})
-}
-
 type Resource struct {
 	dsc.Resource[*Font]
 }
 
 func DSC() *Resource {
 	return &Resource{
-		Resource: dsc.Resource[*Font]{
-			JSONSchemaURL: "https://ohmyposh.dev/dsc.font.schema.json",
-		},
+		Resource: dsc.Resource[*Font]{},
 	}
 }
 
