@@ -1,8 +1,6 @@
 package segments
 
-import (
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-)
+import "github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 
 type Haskell struct {
 	Language
@@ -11,7 +9,7 @@ type Haskell struct {
 }
 
 const (
-	StackGhcMode properties.Property = "stack_ghc_mode"
+	StackGhcMode options.Option = "stack_ghc_mode"
 )
 
 func (h *Haskell) Template() string {
@@ -36,7 +34,7 @@ func (h *Haskell) Enabled() bool {
 	h.commands = []*cmd{ghcCmd}
 	h.versionURLTemplate = "https://www.haskell.org/ghc/download_ghc_{{ .Major }}_{{ .Minor }}_{{ .Patch }}.html"
 
-	switch h.props.GetString(StackGhcMode, "never") {
+	switch h.options.String(StackGhcMode, "never") {
 	case "always":
 		h.commands = []*cmd{stackGhcCmd}
 		h.StackGhc = true
