@@ -4,11 +4,10 @@ import (
 	"errors"
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 
 	"github.com/stretchr/testify/assert"
-	testify_ "github.com/stretchr/testify/mock"
 )
 
 const (
@@ -54,14 +53,13 @@ func TestLFMSegmentSingle(t *testing.T) {
 
 	for _, tc := range cases {
 		env := &mock.Environment{}
-		var props properties.Map = properties.Map{
-			APIKey:                 "key",
-			Username:               "KibbeWater",
-			properties.HTTPTimeout: 20000,
+		props := options.Map{
+			APIKey:              "key",
+			Username:            "KibbeWater",
+			options.HTTPTimeout: 20000,
 		}
 
 		env.On("HTTPRequest", LFMAPIURL).Return([]byte(tc.APIJSONResponse), tc.Error)
-		env.On("Error", testify_.Anything)
 
 		lfm := &LastFM{}
 		lfm.Init(props, env)
