@@ -5,9 +5,9 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 
 	"github.com/alecthomas/assert"
 	testify_ "github.com/stretchr/testify/mock"
@@ -15,19 +15,19 @@ import (
 
 func TestPythonTemplate(t *testing.T) {
 	type ResolveSymlink struct {
-		Path string
 		Err  error
+		Path string
 	}
 	cases := []struct {
+		ResolveSymlink   ResolveSymlink
 		Case             string
 		Expected         string
-		ExpectedDisabled bool
 		Template         string
 		VirtualEnvName   string
-		FetchVersion     bool
 		PythonPath       string
-		ResolveSymlink   ResolveSymlink
 		PyvenvCfg        string
+		ExpectedDisabled bool
+		FetchVersion     bool
 	}{
 		{Case: "No virtual env present", FetchVersion: true, Expected: "3.8.4", Template: "{{ if .Venv }}{{ .Venv }} {{ end }}{{ .Full }}"},
 		{Case: "Virtual env present", FetchVersion: true, Expected: "VENV 3.8.4", VirtualEnvName: "VENV", Template: "{{ if .Venv }}{{ .Venv }} {{ end }}{{ .Full }}"},
@@ -110,7 +110,7 @@ func TestPythonTemplate(t *testing.T) {
 		env.On("PathSeparator").Return("")
 		env.On("ResolveSymlink", testify_.Anything).Return(tc.ResolveSymlink.Path, tc.ResolveSymlink.Err)
 
-		props[properties.FetchVersion] = tc.FetchVersion
+		props[options.FetchVersion] = tc.FetchVersion
 		props[UsePythonVersionFile] = true
 		props[DisplayMode] = DisplayModeAlways
 
@@ -123,8 +123,8 @@ func TestPythonTemplate(t *testing.T) {
 
 func TestPythonPythonInContext(t *testing.T) {
 	cases := []struct {
-		Expected       bool
 		VirtualEnvName string
+		Expected       bool
 	}{
 		{Expected: true, VirtualEnvName: "VENV"},
 		{Expected: false, VirtualEnvName: ""},
@@ -142,7 +142,7 @@ func TestPythonPythonInContext(t *testing.T) {
 		env.On("Getenv", "PYENV_VERSION").Return("")
 		env.On("HasParentFilePath", ".python-version", false).Return(&runtime.FileInfo{}, errors.New("no match at root level"))
 		python := &Python{}
-		python.Init(properties.Map{}, env)
+		python.Init(options.Map{}, env)
 		python.loadContext()
 		assert.Equal(t, tc.Expected, python.inContext())
 	}
@@ -151,8 +151,8 @@ func TestPythonPythonInContext(t *testing.T) {
 func TestPythonVirtualEnvIgnoreDefaultVenvNames(t *testing.T) {
 	cases := []struct {
 		Expected           string
-		FolderNameFallback bool
 		VirtualEnvName     string
+		FolderNameFallback bool
 	}{
 		{
 			Expected:           "folder",
@@ -202,9 +202,9 @@ func TestPythonVirtualEnvIgnoreDefaultVenvNames(t *testing.T) {
 func TestPythonVirtualEnvIgnoreCustomVenvNames(t *testing.T) {
 	cases := []struct {
 		Expected           string
-		FolderNameFallback bool
-		DefaultVenvNames   []string
 		VirtualEnvName     string
+		DefaultVenvNames   []string
+		FolderNameFallback bool
 	}{
 		{
 			Expected:           "folder",
