@@ -6,14 +6,13 @@ import (
 	"path/filepath"
 	"slices"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-
 	"github.com/hashicorp/hcl/v2/gohcl"
 	"github.com/hashicorp/hcl/v2/hclparse"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 )
 
 const (
-	Command properties.Property = "command"
+	Command options.Option = "command"
 )
 
 type Terraform struct {
@@ -36,8 +35,8 @@ type TerraformBlock struct {
 }
 
 func (tf *Terraform) Enabled() bool {
-	cmd := tf.props.GetString(Command, "terraform")
-	fetchVersion := tf.props.GetBool(properties.FetchVersion, false)
+	cmd := tf.options.String(Command, "terraform")
+	fetchVersion := tf.options.Bool(options.FetchVersion, false)
 
 	if !tf.env.HasCommand(cmd) || !tf.inContext(fetchVersion) {
 		return false
