@@ -14,12 +14,15 @@ func funcMap() template.FuncMap {
 		"path":         filePath,
 		"glob":         glob,
 		"matchP":       matchP,
+		"findP":        findP,
 		"replaceP":     replaceP,
 		"gt":           gt,
 		"lt":           lt,
+		"random":       random,
 		"reason":       GetReasonFromStatus,
 		"hresult":      hresult,
 		"trunc":        trunc,
+		"truncE":       TruncE,
 		"readFile":     readFile,
 		"stat":         stat,
 		"dir":          filepath.Dir,
